/* 
 * Stellarium
 * Copyright (C) 2002 Fabien Chreau
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "constellation.h"

extern s_font * nameFont;

constellation::constellation()
{
}

constellation::~constellation()
{	delete Asterism;
}


int constellation::Read(ifstream & list, Star_mgr & VouteCeleste)
// Lis les infos de la constellation et rcupre les x,y et z des etoiles
// Le fichier des constellation doit etre fini sur une ligne vide (faire entree sur la derniere ligne quoi....)
{
char tps[]="00";
char tps4[]="0000";
char lesSegments[300];
unsigned int HR;

#if defined( WIN32 )
	list.read(Name, 21);
	Name[21]='\0';
	//cout << Name;
	list.read(Abreviation, 3);
	Abreviation[3]='\0';
	//cout << Abreviation;
	list.read(Inter, 19);
	Inter[19]='\0';
	//cout << Inter;
	list.read(tps,2);
	NbSegments=atoi(tps);
	//cout << NbSegments << " : ";
   	list.get();
	list.read(lesSegments,NbSegments*2*5-1+1);
	Asterism = new Star*[NbSegments*2];
	for (int i=0;i<NbSegments*2;i++)
	{	strncpy(tps4,lesSegments+i*5,4);		// numero HR
		HR = atoi(tps4);
		//cout << HR << " ";
		Asterism[i]=VouteCeleste.Rechercher(HR);
	}
	//cout << endl;
	//list.ignore(5,'\n');
#endif

#if defined( LINUX )
	list.read(Name, 21);
	Name[21]='\0';
	//cout << Name;
	list.read(Abreviation, 3);
	Abreviation[3]='\0';
	//cout << Abreviation;
	list.read(Inter, 19);
	Inter[19]='\0';
	//cout << Inter;
	list.read(tps,2);
	NbSegments=atoi(tps);
	//cout << NbSegments << " : ";
   	list.get();
	list.read(lesSegments,NbSegments*2*5-1+2);
	Asterism = new Star*[NbSegments*2];
	for (int i=0;i<NbSegments*2;i++)
	{	strncpy(tps4,lesSegments+i*5,4);		// numero HR
		HR = atoi(tps4);
		//cout << HR << " ";
		Asterism[i]=VouteCeleste.Rechercher(HR);
	}
	//cout << endl;
	//list.ignore(5,'\n');
#endif

		Xnom=0;
		Ynom=0;
		Znom=0;
	for(int ii=0;ii<NbSegments*2;ii++)
	{	Xnom+=(*Asterism[ii]).XYZ[0];
		Ynom+=(*Asterism[ii]).XYZ[1];
		Znom+=(*Asterism[ii]).XYZ[2];
	}
	Xnom/=NbSegments*2;
	Ynom/=NbSegments*2;
	Znom/=NbSegments*2;

	return 0;
}

// Draw the lines for the constellation using the coords of the stars (optimized for use with the class Constellation_mgr only)
void constellation::Draw()
{	glPushMatrix();
	for(int i=0;i<NbSegments;i++)
	{	glBegin (GL_LINES);
				glVertex3f((*Asterism[2*i]).XYZ[0],(*Asterism[2*i]).XYZ[1],(*Asterism[2*i]).XYZ[2]);
				glVertex3f((*Asterism[2*i+1]).XYZ[0],(*Asterism[2*i+1]).XYZ[1],(*Asterism[2*i+1]).XYZ[2]);
		glEnd ();
	}
	glPopMatrix();
}

// Same thing but for only one separate constellation (can be used without the class Constellation_mgr )
void constellation::DrawSeule()
{	glDisable(GL_TEXTURE_2D);
	glDisable(GL_BLEND);
	float coef;
	coef=rand();
	coef/=RAND_MAX;
	glColor3f(0.025*coef+0.3,0.025*coef+0.3,0.2*coef+0.3);
	glPushMatrix();
	for(int i=0;i<NbSegments;i++)
	{	glBegin (GL_LINES);
				glVertex3f((*Asterism[2*i]).XYZ[0],(*Asterism[2*i]).XYZ[1],(*Asterism[2*i]).XYZ[2]);
				glVertex3f((*Asterism[2*i+1]).XYZ[0],(*Asterism[2*i+1]).XYZ[1],(*Asterism[2*i+1]).XYZ[2]);
		glEnd ();
	}
	glPopMatrix();
}

// Chek if the constellation is in the field of view and calc the x,y position if true
void constellation::ComputeName()
{	if (acos((global.XYZVision[0]*Xnom+global.XYZVision[1]*Ynom+global.XYZVision[2]*Znom)/RAYON)>((float)global.Fov+4)*PI*1.333333/360)
	{	inFov=false;
		return;	// Si hors du champ
	}
	inFov=true;
	Project(Xnom,Ynom,Znom,x_c ,y_c);
	return;
}

// Draw the name
void constellation::DrawName()
{	if (inFov)
	{	nameFont->print((int)x_c-40,(int)(global.Y_Resolution-y_c), Inter/*Name*/); //"Inter" for internationnal name
	}
}
