/* 
 * Stellarium
 * Copyright (C) 2002 Fabien Chreau
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

// class used to manage groups of Nebulas

#include "nebula_mgr.h"
#include "stellarium.h"
#include "texture.h"

extern double precalculatedFOVNeb;

Nebula_mgr::Nebula_mgr()
{
}

Nebula_mgr::~Nebula_mgr()
{	vector<Nebula *>::iterator iter;
	for(iter=Liste.begin();iter!=Liste.end();iter++)
	{	delete (*iter);
	}
}

// read from stream
int Nebula_mgr::Read(char * fileName)
{	FILE * fic;
	if (fic = fopen(fileName,"rt"))
	{	printf("Loading nebulas data...\n");
		Nebula * e;
		for(;;)
		{	e = new Nebula;
			int temp = e->Read(fic);
			if (temp==0) // fin fichier
			{	delete e;
				break;
			}
			if (temp==1 || temp==2) Liste.push_back(e);
		}
		printf("\n");
		fclose(fic);
	}
	return 0;
}

int Nebula_mgr::ReadTexture()
{	Nebula::texCircleId=createTexture("neb");	// Load circle texture
	vector<Nebula *>::iterator iter;
	for(iter=Liste.begin();iter!=Liste.end();iter++)
	{	if ((*iter)->ReadTexture()==0) return 0;
	}
	return 1;
}

// Draw all the Nebulaes
void Nebula_mgr::Draw()
{	precalculatedFOVNeb=((global.Fov+4.)*PI*((double)global.X_Resolution/global.Y_Resolution)/360.); // Precalc the field of view for optimizations
	glEnable(GL_TEXTURE_2D);
	glEnable(GL_BLEND);
	vector<Nebula *>::iterator iter;
	for(iter=Liste.begin();iter!=Liste.end();iter++)
	{	(**iter).Draw();
	}
}

// Look for a nebulae by XYZ coords
int Nebula_mgr::Rechercher(vec3_t Pos)
{	Pos.Normalize();
	vector<Nebula *>::iterator iter;
	Nebula * plusProche;
	float anglePlusProche=3.15;
	for(iter=Liste.begin();iter!=Liste.end();iter++)
	{	if ((**iter).XYZ[0]*Pos[0]+(**iter).XYZ[1]*Pos[1]+(**iter).XYZ[2]*Pos[2]>anglePlusProche)
		{	anglePlusProche=(**iter).XYZ[0]*Pos[0]+(**iter).XYZ[1]*Pos[1]+(**iter).XYZ[2]*Pos[2];
			plusProche=(*iter);
		}
	}
	if (anglePlusProche>499.9)
	{	Selectionnee=plusProche;
		return 0;
	}
	else return 1;
}

