/* 
 * Stellarium
 * Copyright (C) 2002 Fabien Chreau
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "star.h"

unsigned int Star::starTextureId=0;

static unsigned int HRpasse=0;
static float coef;
static float cmag;
static float rmag;

double precalculatedFOVStar;


Star::Star()
{
}

Star::~Star()
{
}

int Star::Read(FILE * catalog)
// Lis les infos de l'toile dans le fichier et calcule x,y et z;
{	char strTmp[20];
	char ligne[50];
	fgets(ligne,45,catalog);

	strncpy(strTmp,ligne,4);	// HR number
	strTmp[4]='\0';
	HR = atoi(strTmp);

	strncpy(Name,ligne+4,10);	// Name (Flamsteed)
	Name[10]='\0';

	strncpy(strTmp,ligne+14,6);	// SAO number
	strTmp[6]='\0';
	SAO = atoi(strTmp);

	strncpy(strTmp,ligne+20,7);	// RaRad
	strTmp[7]='\0';
	RaRad=atof(strTmp);

	strncpy(strTmp,ligne+27,8);	// DecRad
	strTmp[7]='\0';
	DecRad=atof(strTmp);

    strncpy(strTmp,ligne+35,5);	// Mag
	Mag=atof(strTmp);

	SpType=ligne[40];			// SpType

	if (!(HR%910))
	{	char p=37;
		printf("%i%c ",HR/910*10,p);
	}
	// Calc the Cartesian coord with RA and DE
	RADE_to_XYZ(RaRad,DecRad,XYZ);
	XYZ*=RAYON;


	switch (SpType)			//Couleur en fonction du type spectral
	{	case 'O':	RGB[0]=0.8f;  RGB[1]=1.0f; RGB[2]=1.3f;  break;
		case 'B':	RGB[0]=0.9f;  RGB[1]=1.0f; RGB[2]=1.2f;  break;
		case 'A':	RGB[0]=0.95f; RGB[1]=1.0f; RGB[2]=1.15f; break;
		case 'F':	RGB[0]=1.05f; RGB[1]=1.0f; RGB[2]=1.05f; break;
		case 'G':	RGB[0]=1.3f;  RGB[1]=1.0f; RGB[2]=0.9f;  break;
		case 'K':	RGB[0]=1.15f; RGB[1]=0.95f;RGB[2]=0.8f;  break;
		case 'M':
		case 'C':	RGB[0]=1.3f;  RGB[1]=0.85f;RGB[2]=0.6f;  break;
		case 'S':	RGB[0]=1.5f;  RGB[1]=0.8f; RGB[2]=0.2f;  break;
	}

	return 0;
}




void Star::Draw(void)
{	/*if (Mag>MAX_MAG) return;*/

	// Check if in the field of view, if not return
	if (XY[0]<0 || XY[0]>global.X_Resolution || XY[1]<0 || XY[1]>global.Y_Resolution) return;
	// Random coef for star twinkling
	coef=(double)rand()/RAND_MAX;

	// Calculation of the demi-size of the star texture
	float L=pow(100,-Mag/4.);
	float leMax=myMax(RGB[0],RGB[2]);
	rmag = sqrt(L/(pow(L,0.46666)+7.079))*sqrt(leMax)*1./pow(global.Fov,0.85)*1200;

	cmag = 1;
	
	//if size of star is too small (blink) we put it to 1 --> no more blink
	// And we compensate the difference of brighteness with cmag
	if (rmag<1.2) 
	{	if (rmag<0.5) return;
		cmag=pow(rmag,2)/1.44;
		rmag=1.2;
	}

	if (rmag>4) 
	{	rmag=4;
	}

	// Calculation of the luminosity
	cmag*=(1-coef*global.Fov/240);

	glColor3fv(RGB/(leMax)*cmag);

	glPushMatrix();
	glLoadIdentity();
	glTranslatef((float)XY[0],global.Y_Resolution-(float)XY[1],0);
	glBegin(GL_QUADS );
		glTexCoord2f(0.0f,0.0f);	glVertex3f(-rmag,-rmag,0);		//Bas Gauche
		glTexCoord2f(1.0f,0.0f);	glVertex3f(rmag,-rmag,0);		//Bas Droite
		glTexCoord2f(1.0f,1.0f);	glVertex3f(rmag,rmag,0);		//Haut Droit
		glTexCoord2f(0.0f,1.0f);	glVertex3f(-rmag,rmag,0);		//Haut Gauche
	glEnd ();
	glPopMatrix();

}

