/* 
 * Stellarium
 * Copyright (C) 2002 Fabien Chreau
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef _STELLA_TYPE_H_
#define _STELLA_TYPE_H_

#include "vector.h"
#include "astroLib/AstroOps.h"

typedef struct			// Struct used to store data on the selected star
{	vec3_t XYZ;
	float Mag;
	char * Name;
	unsigned int HR;
	unsigned int MessierNum;
	unsigned int NGCNum;
	float Size;
	float RA,DE;
	int RAh,RAm;
	double Distance;
	float RAs;
	vec3_t RGB;
	char * CommonName;
	char type;
}selected_object;


typedef struct params{
	// Navigation
	double RaZenith,DeZenith;
	double AzVision,AltVision;
	double deltaFov,deltaDe,deltaRa;
	double Fov;
	vec3_t XYZVisionAltAz,XYZVision;
	vec3_t Pointer;
	selected_object SelectedObject;

	// Position
	ObsInfo ThePlace;	//(Longitude,Latitude, -2);
	double JDay;		// Julian day

	// technical params
	int X_Resolution;
	int Y_Resolution;
	int bppMode;
	bool Fullscreen;

	//FPS Calc and time measurement
	float Fps;
	int Frame;
	int Timefr;
	int Timebase;

	// Drawing
	float SkyBrightness;

	// Flags
	bool FlagFps;
	bool FlagStars;
	bool FlagPlanets;
	bool FlagNebula;
	bool FlagGround;
	bool FlagHorizon;
	bool FlagFog;
	bool FlagAtmosphere;
	bool FlagConstellationDrawing;
	bool FlagConstellationName;
	bool FlagAzimutalGrid;
	bool FlagEquatorialGrid;
	bool FlagEquator;
	bool FlagEcliptic;
	bool FlagCardinalPoints;
	bool FlagRealMode;
	bool FlagRealTime;
	bool FlagAcceleredTime;
	bool FlagVeryFastTime;
	bool FlagMenu;
	bool FlagHelp;
	bool FlagInfos;
	bool FlagSelect;

} stellariumParams;

#endif /*_STELLA_TYPE_H_*/
